@@ -24,6 +24,12 @@
 #include "qsynthOptions.h"
 #include "qsynthMainForm.h"
 
+#include "qsynthPaletteForm.h"
+
+#include <QDir>
+
+#include <QStyleFactory>
+
 #include <QLibraryInfo>
 #include <QTranslator>
 #include <QLocale>
@@ -44,6 +50,20 @@ const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
 #define CONFIG_DATADIR	CONFIG_PREFIX "/share"
 #endif
 
+#ifndef CONFIG_LIBDIR
+#if defined(__x86_64__)
+#define CONFIG_LIBDIR  CONFIG_PREFIX "/lib64"
+#else
+#define CONFIG_LIBDIR  CONFIG_PREFIX "/lib"
+#endif
+#endif
+
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
+#define CONFIG_PLUGINSDIR CONFIG_LIBDIR "/qt4/plugins"
+#else
+#define CONFIG_PLUGINSDIR CONFIG_LIBDIR "/qt5/plugins"
+#endif
+
 
 //-------------------------------------------------------------------------
 // Singleton application instance stuff (Qt/X11 only atm.)
@@ -75,8 +95,13 @@ const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
 // Constructor.
 qsynthApplication::qsynthApplication ( int& argc, char **argv )
 	: QApplication(argc, argv),
-		m_pQtTranslator(NULL), m_pMyTranslator(NULL), m_pWidget(NULL)
+		m_pQtTranslator(nullptr), m_pMyTranslator(nullptr), m_pWidget(nullptr)
 {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 1, 0)
+	QApplication::setApplicationName(QSYNTH_TITLE);
+	QApplication::setApplicationDisplayName(QSYNTH_TITLE);
+	//	QSYNTH_TITLE " - " + QObject::tr(QSYNTH_SUBTITLE));
+#endif
 	// Load translation support.
 	QLocale loc;
 	if (loc.language() != QLocale::C) {
@@ -88,7 +113,7 @@ qsynthApplication::qsynthApplication ( int& argc, char **argv )
 			QApplication::installTranslator(m_pQtTranslator);
 		} else {
 			delete m_pQtTranslator;
-			m_pQtTranslator = 0;
+			m_pQtTranslator = nullptr;
 		#ifdef CONFIG_DEBUG
 			qWarning("Warning: no translation found for '%s' locale: %s/%s.qm",
 				loc.name().toLocal8Bit().data(),
@@ -107,7 +132,7 @@ qsynthApplication::qsynthApplication ( int& argc, char **argv )
 				QApplication::installTranslator(m_pMyTranslator);
 			} else {
 				delete m_pMyTranslator;
-				m_pMyTranslator = 0;
+				m_pMyTranslator = nullptr;
 			#ifdef CONFIG_DEBUG
 				qWarning("Warning: no translation found for '%s' locale: %s/%s.qm",
 					loc.name().toLocal8Bit().data(),
@@ -120,13 +145,13 @@ qsynthApplication::qsynthApplication ( int& argc, char **argv )
 #ifdef CONFIG_XUNIQUE
 #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 #ifdef CONFIG_X11
-	m_pDisplay = NULL;
+	m_pDisplay = nullptr;
 	m_aUnique = 0;
 	m_wOwner = 0;
 #endif	// CONFIG_X11
 #else
-	m_pMemory = NULL;
-	m_pServer = NULL;
+	m_pMemory = nullptr;
+	m_pServer = nullptr;
 #endif
 #endif	// CONFIG_XUNIQUE
 }
@@ -140,11 +165,11 @@ qsynthApplication::~qsynthApplication (void)
 	if (m_pServer) {
 		m_pServer->close();
 		delete m_pServer;
-		m_pServer = NULL;
+		m_pServer = nullptr;
 	}
 	if (m_pMemory) {
 		delete m_pMemory;
-		m_pMemory = NULL;
+		m_pMemory = nullptr;
 }
 #endif
 #endif	// CONFIG_XUNIQUE
@@ -358,7 +383,7 @@ void qsynthApplication::readyReadSlot (void)
 	if (pSocket) {
 		const qint64 nread = pSocket->bytesAvailable();
 		if (nread > 0) {
-			QByteArray data = pSocket->read(nread);
+			const QByteArray data = pSocket->read(nread);
 			// Just make it always shows up fine...
 			m_pWidget->hide();
 			m_pWidget->show();
@@ -414,7 +439,7 @@ void stacktrace ( int signo )
 
 	// Fork child...
 	if (pid == 0) {
-		execl(shell, shell, "-c", cmd, NULL);
+		execl(shell, shell, "-c", cmd, nullptr);
 		_exit(1);
 		return;
 	}
@@ -451,13 +476,15 @@ int main ( int argc, char **argv )
 	::signal(SIGBUS,  stacktrace);
 #endif
 #endif
-	qsynthApplication app(argc, argv);
 #if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
-	app.setAttribute(Qt::AA_EnableHighDpiScaling);
+	QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 #endif
+
+	qsynthApplication app(argc, argv);
+
 	// Construct default settings; override with command line arguments.
-	qsynthOptions settings;
-	if (!settings.parse_args(app.arguments())) {
+	qsynthOptions options;
+	if (!options.parse_args(app.arguments())) {
 		app.quit();
 		return 1;
 	}
@@ -468,38 +495,21 @@ int main ( int argc, char **argv )
 		return 2;
 	}
 
-	// Dark themes grayed/disabled color group fix...
+	// Special custom styles...
+	if (QDir(CONFIG_PLUGINSDIR).exists())
+		app.addLibraryPath(CONFIG_PLUGINSDIR);
+	if (!options.sCustomStyleTheme.isEmpty())
+		app.setStyle(QStyleFactory::create(options.sCustomStyleTheme));
+
+	// Custom color theme (eg. "KXStudio")...
 	QPalette pal(app.palette());
-	if (pal.base().color().value() < 0x7f) {
-	#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-		const QColor& color = pal.window().color();
-		const int iGroups = int(QPalette::Active | QPalette::Inactive) + 1;
-		for (int i = 0; i < iGroups; ++i) {
-			const QPalette::ColorGroup group = QPalette::ColorGroup(i);
-			pal.setBrush(group, QPalette::Light,    color.lighter(150));
-			pal.setBrush(group, QPalette::Midlight, color.lighter(120));
-			pal.setBrush(group, QPalette::Dark,     color.darker(150));
-			pal.setBrush(group, QPalette::Mid,      color.darker(120));
-			pal.setBrush(group, QPalette::Shadow,   color.darker(200));
-		}
-	//	pal.setColor(QPalette::Disabled, QPalette::ButtonText, pal.mid().color());
-	#endif
-		pal.setColorGroup(QPalette::Disabled,
-			pal.windowText().color().darker(),
-			pal.button(),
-			pal.light(),
-			pal.dark(),
-			pal.mid(),
-			pal.text().color().darker(),
-			pal.text().color().lighter(),
-			pal.base(),
-			pal.window());
+	if (qsynthPaletteForm::namedPalette(
+			&options.settings(), options.sCustomColorTheme, pal))
 		app.setPalette(pal);
-	}
 
 	// Set default base font...
-	if (settings.iBaseFontSize > 0)
-		app.setFont(QFont(app.font().family(), settings.iBaseFontSize));
+	if (options.iBaseFontSize > 0)
+		app.setFont(QFont(app.font().family(), options.iBaseFontSize));
 
 	// What style do we create these forms?
 	Qt::WindowFlags wflags = Qt::Window
@@ -508,13 +518,13 @@ int main ( int argc, char **argv )
 		| Qt::WindowSystemMenuHint
 		| Qt::WindowMinMaxButtonsHint
 		| Qt::WindowCloseButtonHint;
-	if (settings.bKeepOnTop)
+	if (options.bKeepOnTop)
 		wflags |= Qt::Tool;
 	// Construct the main form, and show it to the world.
-	qsynthMainForm w(0, wflags);
-	w.setup(&settings);
+	qsynthMainForm w(nullptr, wflags);
+	w.setup(&options);
 	// If we have a systray icon, we'll skip this.
-	if (!settings.bSystemTray) {
+	if (!options.bSystemTray) {
 		w.show();
 	//	w.adjustSize();
 	}
@@ -534,5 +544,6 @@ int main ( int argc, char **argv )
 	return app.exec();
 }
 
+
 // end of qsynth.cpp
 
