@@ -24,6 +24,8 @@
 
 #include "ui_qsynthMainForm.h"
 
+#include <QMenu>
+
 
 // Forward declarations
 class qsynthOptions;
@@ -57,10 +59,10 @@ public:
 
 	void setup(qsynthOptions *pOptions);
 
-	void appendMessages(const QString& s);
-	void appendMessagesColor(const QString& s, const QString& c);
-	void appendMessagesText(const QString& s);
-	void appendMessagesError(const QString& s);
+	void appendMessages(const QString& sText);
+	void appendMessagesColor(const QString& sText, const QString& sColor);
+	void appendMessagesText(const QString& sText);
+	void appendMessagesError(const QString& sText);
 
 	bool deleteEngineTab(qsynthEngine *pEngine, int iTab);
 	bool setupEngineTab(qsynthEngine *pEngine, int iTab);
@@ -76,17 +78,14 @@ public:
 
 	enum KnobStyle { Classic, Vokimon, Peppino, Skulpture, Legacy };
 
-public slots:
-
 	void stabilizeForm();
+	void stabilizeFormEx();
 
 protected slots:
 
 	void stdoutNotifySlot(int);
 	void sigtermNotifySlot(int);
 
-	void contextMenu(const QPoint&);
-
 	void programReset();
 	void systemReset();
 	void promptRestart();
@@ -127,12 +126,12 @@ protected:
 
 	void closeEvent(QCloseEvent *pCloseEvent);
 
-	void appendStdoutBuffer(const QString&);
+	void appendStdoutBuffer(const QString& sText);
 	void flushStdoutBuffer();
 
 	bool stdoutBlock(int fd, bool bBlock) const;
 
-	void playLoadFiles( qsynthEngine *pEngine, const QStringList& files, bool bSetup);
+	void playLoadFiles(qsynthEngine *pEngine, const QStringList& files, bool bSetup);
 
 	bool decodeDragFiles(const QMimeSource *pEvent, QStringList& files);
 	void dragEnterEvent(QDragEnterEvent *pDragEnterEvent);
@@ -145,6 +144,8 @@ protected:
 	void updateSystemTray();
 #endif
 
+	void updateContextMenu();
+
 	qsynthEngine *currentEngine() const;
 
 	void setEngineGain(qsynthEngine *pEngine, float fGain);
@@ -210,11 +211,14 @@ private:
 
 	bool m_bQuitForce;
 
+	// Common context menu.
+	QMenu m_menu;
+
 	// Kind-of singleton reference.
 	static qsynthMainForm *g_pMainForm;
 
 	// Style for qsynthKnob (QDial) widgets
-	QStyle* m_pKnobStyle;
+	QStyle* m_pKnobStyle;	
 };
 
 
