@@ -1,7 +1,7 @@
 // qsynthMessagesForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2018, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -55,7 +55,7 @@ qsynthMessagesForm::qsynthMessagesForm (
 	m_iMessagesLines = 0;
 	setMessagesLimit(QSYNTH_MESSAGES_MAXLINES);
 
-	m_pMessagesLog = NULL;
+	m_pMessagesLog = nullptr;
 }
 
 
@@ -71,11 +71,12 @@ void qsynthMessagesForm::showEvent ( QShowEvent *pShowEvent )
 {
 	qsynthMainForm *pMainForm = qsynthMainForm::getInstance();
 	if (pMainForm)
-		pMainForm->stabilizeForm();
+		pMainForm->stabilizeFormEx();
 
 	QWidget::showEvent(pShowEvent);
 }
 
+
 // Notify our parent that we're closing.
 void qsynthMessagesForm::hideEvent ( QHideEvent *pHideEvent )
 {
@@ -83,17 +84,7 @@ void qsynthMessagesForm::hideEvent ( QHideEvent *pHideEvent )
 
 	qsynthMainForm *pMainForm = qsynthMainForm::getInstance();
 	if (pMainForm)
-		pMainForm->stabilizeForm();
-}
-
-// Just about to notify main-window that we're closing.
-void qsynthMessagesForm::closeEvent ( QCloseEvent * /*pCloseEvent*/ )
-{
-	QWidget::hide();
-
-	qsynthMainForm *pMainForm = qsynthMainForm::getInstance();
-	if (pMainForm)
-		pMainForm->stabilizeForm();
+		pMainForm->stabilizeFormEx();
 }
 
 
@@ -127,7 +118,7 @@ void qsynthMessagesForm::setMessagesLimit ( int iMessagesLimit )
 // Messages logging stuff.
 bool qsynthMessagesForm::isLogging (void) const
 {
-	return (m_pMessagesLog != NULL);
+	return (m_pMessagesLog != nullptr);
 }
 
 void qsynthMessagesForm::setLogging ( bool bEnabled, const QString& sFilename )
@@ -137,7 +128,7 @@ void qsynthMessagesForm::setLogging ( bool bEnabled, const QString& sFilename )
 			.arg(QDateTime::currentDateTime().toString()));
 		m_pMessagesLog->close();
 		delete m_pMessagesLog;
-		m_pMessagesLog = NULL;
+		m_pMessagesLog = nullptr;
 	}
 
 	if (bEnabled) {
@@ -147,7 +138,7 @@ void qsynthMessagesForm::setLogging ( bool bEnabled, const QString& sFilename )
 				.arg(QDateTime::currentDateTime().toString()));
 		} else {
 			delete m_pMessagesLog;
-			m_pMessagesLog = NULL;
+			m_pMessagesLog = nullptr;
 		}
 	}
 }
