@@ -27,6 +27,9 @@
 #include <QTextStream>
 #include <QComboBox>
 
+#include <QApplication>
+#include <QDesktopWidget>
+
 
 //-------------------------------------------------------------------------
 // qsynthOptions - Prototype settings structure.
@@ -52,13 +55,21 @@ qsynthOptions::~qsynthOptions (void)
 
 	// Delete default setup descriptor.
 	delete m_pDefaultSetup;
-	m_pDefaultSetup = NULL;
+	m_pDefaultSetup = nullptr;
 }
 
 
+
+
 // Explicit load method.
 void qsynthOptions::loadOptions (void)
 {
+	// Load defaults...
+	m_settings.beginGroup("/Defaults");
+	sSoundFontDir  = m_settings.value("/SoundFontDir").toString();
+	bPresetPreview = m_settings.value("/PresetPreview", false).toBool();
+	m_settings.endGroup();
+
 	// Load display options...
 	m_settings.beginGroup("/Options");
 	sMessagesFont   = m_settings.value("/MessagesFont").toString();
@@ -78,10 +89,10 @@ void qsynthOptions::loadOptions (void)
 	iKnobMotion     = m_settings.value("/KnobMotion", 1).toInt();
 	m_settings.endGroup();
 
-	// Load defaults...
-	m_settings.beginGroup("/Defaults");
-	sSoundFontDir  = m_settings.value("/SoundFontDir").toString();
-	bPresetPreview = m_settings.value("/PresetPreview", false).toBool();
+	// Load custom options...
+	m_settings.beginGroup("/Custom");
+	sCustomColorTheme = m_settings.value("/ColorTheme").toString();
+	sCustomStyleTheme = m_settings.value("/StyleTheme").toString();
 	m_settings.endGroup();
 
 	// Load custom additional engines.
@@ -106,26 +117,13 @@ void qsynthOptions::saveOptions (void)
 	m_settings.setValue("/Version", CONFIG_BUILD_VERSION);
 	m_settings.endGroup();
 
-	// Save engines list...
-	m_settings.beginGroup("/Engines");
-	// Save last preset list.
-	const QString sEnginePrefix = "/Engine%1";
-	int iEngine = 0;
-	QStringListIterator iter(engines);
-	while (iter.hasNext())
-		m_settings.setValue(sEnginePrefix.arg(++iEngine), iter.next());
-	// Cleanup old entries, if any...
-	while (!m_settings.value(sEnginePrefix.arg(++iEngine)).toString().isEmpty())
-		m_settings.remove(sEnginePrefix.arg(iEngine));
-	m_settings.endGroup();
-
 	// Save defaults...
 	m_settings.beginGroup("/Defaults");
 	m_settings.setValue("/SoundFontDir", sSoundFontDir);
 	m_settings.setValue("/PresetPreview", bPresetPreview);
 	m_settings.endGroup();
 
-	// Save last display options.
+	// Save display options...
 	m_settings.beginGroup("/Options");
 	m_settings.setValue("/MessagesFont", sMessagesFont);
 	m_settings.setValue("/MessagesLimit", bMessagesLimit);
@@ -144,6 +142,25 @@ void qsynthOptions::saveOptions (void)
 	m_settings.setValue("/KnobMotion", iKnobMotion);
 	m_settings.endGroup();
 
+	// Save custom options...
+	m_settings.beginGroup("/Custom");
+	m_settings.setValue("/ColorTheme", sCustomColorTheme);
+	m_settings.setValue("/StyleTheme", sCustomStyleTheme);
+	m_settings.endGroup();
+
+	// Save engines list...
+	m_settings.beginGroup("/Engines");
+	// Save last preset list.
+	const QString sEnginePrefix = "/Engine%1";
+	int iEngine = 0;
+	QStringListIterator iter(engines);
+	while (iter.hasNext())
+		m_settings.setValue(sEnginePrefix.arg(++iEngine), iter.next());
+	// Cleanup old entries, if any...
+	while (!m_settings.value(sEnginePrefix.arg(++iEngine)).toString().isEmpty())
+		m_settings.remove(sEnginePrefix.arg(iEngine));
+	m_settings.endGroup();
+
 	// Save/commit to disk.
 	m_settings.sync();
 }
@@ -156,6 +173,16 @@ qsynthSetup *qsynthOptions::defaultSetup (void)
 }
 
 
+//-------------------------------------------------------------------------
+// Settings accessor.
+//
+
+QSettings& qsynthOptions::settings (void)
+{
+	return m_settings;
+}
+
+
 //-------------------------------------------------------------------------
 // Command-line argument stuff. Mostly to mimic fluidsynth CLI.
 //
@@ -219,8 +246,8 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 {
 	QTextStream out(stderr);
 	const QString sEol = "\n\n";
-	int iSoundFontOverride = 0;
 	const int argc = args.count();
+	int iSoundFontOverride = 0;
 
 	for (int i = 1; i < argc; ++i) {
 
@@ -247,7 +274,7 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 			}
 			m_pDefaultSetup->sMidiDriver = sVal;
 			if (iEqual < 0)
-				i++;
+				++i;
 		}
 		else if (sArg == "-K" || sArg == "--midi-channels") {
 			if (sVal.isEmpty()) {
@@ -256,7 +283,7 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 			}
 			m_pDefaultSetup->iMidiChannels = sVal.toInt();
 			if (iEqual < 0)
-				i++;
+				++i;
 		}
 		else if (sArg == "-a" || sArg == "--audio-driver") {
 			if (sVal.isEmpty()) {
@@ -265,7 +292,7 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 			}
 			m_pDefaultSetup->sAudioDriver = sVal;
 			if (iEqual < 0)
-				i++;
+				++i;
 		}
 		else if (sArg == "-j" || sArg == "--connect-jack-outputs") {
 			m_pDefaultSetup->bJackAutoConnect = true;
@@ -277,7 +304,7 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 			}
 			m_pDefaultSetup->iAudioChannels = sVal.toInt();
 			if (iEqual < 0)
-				i++;
+				++i;
 		}
 		else if (sArg == "-G" || sArg == "--audio-groups") {
 			if (sVal.isEmpty()) {
@@ -295,7 +322,7 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 			}
 			m_pDefaultSetup->iAudioBufSize = sVal.toInt();
 			if (iEqual < 0)
-				i++;
+				++i;
 		}
 		else if (sArg == "-c" || sArg == "--audio-bufcount") {
 			if (sVal.isEmpty()) {
@@ -304,7 +331,7 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 			}
 			m_pDefaultSetup->iAudioBufCount = sVal.toInt();
 			if (iEqual < 0)
-				i++;
+				++i;
 		}
 		else if (sArg == "-r" || sArg == "--sample-rate") {
 			if (sVal.isEmpty()) {
@@ -313,7 +340,7 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 			}
 			m_pDefaultSetup->fSampleRate = sVal.toFloat();
 			if (iEqual < 0)
-				i++;
+				++i;
 		}
 		else if (sArg == "-R" || sArg == "--reverb") {
 			if (sVal.isEmpty()) {
@@ -321,7 +348,7 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 			} else {
 				m_pDefaultSetup->bReverbActive = !(sVal == "0" || sVal == "no" || sVal == "off");
 				if (iEqual < 0)
-					i++;
+					++i;
 			}
 		}
 		else if (sArg == "-C" || sArg == "--chorus") {
@@ -330,7 +357,7 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 			} else {
 				m_pDefaultSetup->bChorusActive = !(sVal == "0" || sVal == "no" || sVal == "off");
 				if (iEqual < 0)
-					i++;
+					++i;
 			}
 		}
 		else if (sArg == "-g" || sArg == "--gain") {
@@ -340,7 +367,7 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 			}
 			m_pDefaultSetup->fGain = sVal.toFloat();
 			if (iEqual < 0)
-				i++;
+				++i;
 		}
 		else if (sArg == "-o" || sArg == "--option") {
 			if (++i >= argc) {
@@ -353,7 +380,7 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 			m_pDefaultSetup->bServer = true;
 		}
 		else if (sArg == "-i" || sArg == "--no-shell") {
-			// Just ignore this...
+			// Just ignore this one...
 		}
 		else if (sArg == "-d" || sArg == "--dump") {
 			m_pDefaultSetup->bMidiDump = true;
@@ -407,7 +434,7 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 
 void qsynthOptions::newEngine ( qsynthEngine *pEngine )
 {
-	if (pEngine == NULL)
+	if (pEngine == nullptr)
 		return;
 	if (pEngine->isDefault())
 		return;
@@ -420,11 +447,11 @@ void qsynthOptions::newEngine ( qsynthEngine *pEngine )
 
 bool qsynthOptions::renameEngine ( qsynthEngine *pEngine )
 {
-	if (pEngine == NULL)
+	if (pEngine == nullptr)
 		return false;
 
 	qsynthSetup *pSetup = pEngine->setup();
-	if (pSetup == NULL)
+	if (pSetup == nullptr)
 		return false;
 
 	const QString sOldName = pEngine->name();
@@ -445,7 +472,7 @@ bool qsynthOptions::renameEngine ( qsynthEngine *pEngine )
 
 void qsynthOptions::deleteEngine ( qsynthEngine *pEngine )
 {
-	if (pEngine == NULL)
+	if (pEngine == nullptr)
 		return;
 	if (pEngine->isDefault())
 		return;
@@ -465,7 +492,7 @@ void qsynthOptions::deleteEngine ( qsynthEngine *pEngine )
 // Load instance m_settings.
 void qsynthOptions::loadSetup ( qsynthSetup *pSetup, const QString& sName )
 {
-	if (pSetup == NULL)
+	if (pSetup == nullptr)
 		return;
 
 	// Begin at key group?
@@ -475,7 +502,7 @@ void qsynthOptions::loadSetup ( qsynthSetup *pSetup, const QString& sName )
 	// Shall we have a default display name.
 	QString sDisplayName = sName;
 	if (sDisplayName.isEmpty())
-		sDisplayName = QObject::tr(QSYNTH_TITLE "1");
+		sDisplayName = QSYNTH_TITLE "1";
 
 	// Load previous/default fluidsynth m_settings...
 	m_settings.beginGroup("/Settings");
@@ -487,6 +514,9 @@ void qsynthOptions::loadSetup ( qsynthSetup *pSetup, const QString& sName )
 #elif defined(__WIN32__) || defined(_WIN32) || defined(WIN32)
 	pSetup->sMidiDriver      = m_settings.value("/MidiDriver", "winmidi").toString();
 	pSetup->sAudioDriver     = m_settings.value("/AudioDriver", "dsound").toString();
+#elif defined(__OpenBSD__)
+	pSetup->sMidiDriver      = m_settings.value("/MidiDriver", "sndio").toString();
+	pSetup->sAudioDriver     = m_settings.value("/AudioDriver", "sndio").toString();
 #else
 	pSetup->sMidiDriver      = m_settings.value("/MidiDriver", "alsa_seq").toString();
 	pSetup->sAudioDriver     = m_settings.value("/AudioDriver", "jack").toString();
@@ -502,7 +532,11 @@ void qsynthOptions::loadSetup ( qsynthSetup *pSetup, const QString& sName )
 	pSetup->sJackName        = m_settings.value("/JackName", "qsynth").toString();
 	pSetup->bJackAutoConnect = m_settings.value("/JackAutoConnect", true).toBool();
 	pSetup->bJackMulti       = m_settings.value("/JackMulti", false).toBool();
+#if defined(__OpenBSD__)
+	pSetup->sMidiDevice      = m_settings.value("/MidiDevice", "midithru/0").toString();
+#else
 	pSetup->sMidiDevice      = m_settings.value("/MidiDevice").toString();
+#endif
 	pSetup->iMidiChannels    = m_settings.value("/MidiChannels", 16).toInt();
 	pSetup->sMidiBankSelect  = m_settings.value("/MidiBankSelect", "gm").toString();
 	pSetup->sAudioDevice     = m_settings.value("/AudioDevice").toString();
@@ -567,7 +601,7 @@ void qsynthOptions::loadSetup ( qsynthSetup *pSetup, const QString& sName )
 // Save instance m_settings.
 void qsynthOptions::saveSetup ( qsynthSetup *pSetup, const QString& sName )
 {
-	if (pSetup == NULL)
+	if (pSetup == nullptr)
 		return;
 
 	// Begin at key group?
@@ -657,11 +691,11 @@ void qsynthOptions::saveSetup ( qsynthSetup *pSetup, const QString& sName )
 
 bool qsynthOptions::loadPreset ( qsynthEngine *pEngine, const QString& sPreset )
 {
-	if (pEngine == NULL || pEngine->pSynth == NULL)
+	if (pEngine == nullptr || pEngine->pSynth == nullptr)
 		return false;
 
 	qsynthSetup *pSetup = pEngine->setup();
-	if (pSetup == NULL)
+	if (pSetup == nullptr)
 		return false;
 
 	QString sSuffix;
@@ -726,11 +760,11 @@ bool qsynthOptions::loadPreset ( qsynthEngine *pEngine, const QString& sPreset )
 
 bool qsynthOptions::savePreset ( qsynthEngine *pEngine, const QString& sPreset )
 {
-	if (pEngine == NULL || pEngine->pSynth == NULL)
+	if (pEngine == nullptr || pEngine->pSynth == nullptr)
 		return false;
 
 	qsynthSetup *pSetup = pEngine->setup();
-	if (pSetup == NULL)
+	if (pSetup == nullptr)
 		return false;
 
 	QString sSuffix;
@@ -819,11 +853,11 @@ bool qsynthOptions::savePreset ( qsynthEngine *pEngine, const QString& sPreset )
 
 bool qsynthOptions::deletePreset ( qsynthEngine *pEngine, const QString& sPreset )
 {
-	if (pEngine == NULL)
+	if (pEngine == nullptr)
 		return false;
 
 	qsynthSetup *pSetup = pEngine->setup();
-	if (pSetup == NULL)
+	if (pSetup == nullptr)
 		return false;
 
 	QString sPrefix;
@@ -920,8 +954,20 @@ void qsynthOptions::loadWidgetGeometry ( QWidget *pWidget, bool bVisible )
 	#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 		const QByteArray& geometry
 			= m_settings.value("/geometry").toByteArray();
-		if (!geometry.isEmpty())
+		if (geometry.isEmpty()) {
+			QWidget *pParent = pWidget->parentWidget();
+			if (pParent)
+				pParent = pParent->window();
+			if (pParent == nullptr)
+				pParent = QApplication::desktop();
+			if (pParent) {
+				QRect wrect(pWidget->geometry());
+				wrect.moveCenter(pParent->geometry().center());
+				pWidget->move(wrect.topLeft());
+			}
+		} else {
 			pWidget->restoreGeometry(geometry);
+		}
 	#else//--LOAD_OLD_GEOMETRY
 		QPoint wpos;
 		QSize  wsize;
