@@ -1,7 +1,7 @@
 // qsynthOptionsForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2018, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -22,6 +22,8 @@
 #include "qsynthAbout.h"
 #include "qsynthOptionsForm.h"
 
+#include "qsynthPaletteForm.h"
+
 #include "qsynthOptions.h"
 
 #include <QValidator>
@@ -29,11 +31,17 @@
 #include <QFontDialog>
 #include <QFileDialog>
 
+#include <QStyleFactory>
+
 #ifdef CONFIG_SYSTEM_TRAY
 #include <QSystemTrayIcon>
 #endif
 
 
+// Default (empty/blank) name.
+static const char *g_pszDefName = QT_TRANSLATE_NOOP("qsynthOptionsForm", "(default)");
+
+
 //----------------------------------------------------------------------------
 // qsynthOptionsForm -- UI wrapper form.
 
@@ -46,7 +54,7 @@ qsynthOptionsForm::qsynthOptionsForm (
 	m_ui.setupUi(this);
 
 	// No options descriptor initially (the caller will set it).
-	m_pOptions = NULL;
+	m_pOptions = nullptr;
 
 	// Initialize dirty control state.
 	m_iDirtySetup = 0;
@@ -94,6 +102,15 @@ qsynthOptionsForm::qsynthOptionsForm (
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
 #endif
+	QObject::connect(m_ui.CustomColorThemeComboBox,
+		SIGNAL(activated(int)),
+		SLOT(optionsChanged()));
+	QObject::connect(m_ui.CustomColorThemeToolButton,
+		SIGNAL(clicked()),
+		SLOT(editCustomColorThemes()));
+	QObject::connect(m_ui.CustomStyleThemeComboBox,
+		SIGNAL(activated(int)),
+		SLOT(optionsChanged()));
 	QObject::connect(m_ui.BaseFontSizeComboBox,
 		SIGNAL(editTextChanged(const QString&)),
 		SLOT(optionsChanged()));
@@ -200,6 +217,10 @@ void qsynthOptionsForm::setup ( qsynthOptions *pOptions )
 		m_ui.StartMinimizedCheckBox->setEnabled(false);
 	}
 
+	// Custom display options...
+	resetCustomColorThemes(m_pOptions->sCustomColorTheme);
+	resetCustomStyleThemes(m_pOptions->sCustomStyleTheme);
+
 	// Done.
 	m_iDirtySetup--;
 	stabilizeForm();
@@ -229,6 +250,45 @@ void qsynthOptionsForm::accept (void)
 		// Knobs
 		m_pOptions->iKnobStyle      = m_ui.KnobStyleComboBox->currentIndex();
 		m_pOptions->iKnobMotion     = m_ui.KnobMouseMotionComboBox->currentIndex();
+		// Custom color/style theme options...
+		const QString sOldCustomStyleTheme = m_pOptions->sCustomStyleTheme;
+		if (m_ui.CustomStyleThemeComboBox->currentIndex() > 0)
+			m_pOptions->sCustomStyleTheme = m_ui.CustomStyleThemeComboBox->currentText();
+		else
+			m_pOptions->sCustomStyleTheme.clear();
+		const QString sOldCustomColorTheme = m_pOptions->sCustomColorTheme;
+		if (m_ui.CustomColorThemeComboBox->currentIndex() > 0)
+			m_pOptions->sCustomColorTheme = m_ui.CustomColorThemeComboBox->currentText();
+		else
+			m_pOptions->sCustomColorTheme.clear();
+		// Check whether restart is needed or whether
+		// custom options maybe set up immediately...
+		int iNeedRestart = 0;
+		if (m_pOptions->sCustomStyleTheme != sOldCustomStyleTheme) {
+			if (m_pOptions->sCustomStyleTheme.isEmpty()) {
+				++iNeedRestart;
+			} else {
+				QApplication::setStyle(
+					QStyleFactory::create(m_pOptions->sCustomStyleTheme));
+			}
+		}
+		if (m_pOptions->sCustomColorTheme != sOldCustomColorTheme) {
+			if (m_pOptions->sCustomColorTheme.isEmpty()) {
+				++iNeedRestart;
+			} else {
+				QPalette pal;
+				if (qsynthPaletteForm::namedPalette(
+						&m_pOptions->settings(), m_pOptions->sCustomColorTheme, pal))
+					QApplication::setPalette(pal);
+			}
+		}
+		// Show restart message if needed...
+		if (iNeedRestart > 0) {
+			QMessageBox::information(this,
+				tr("Information"),
+				tr("Some settings may be only effective\n"
+				"next time you start this application."));
+		}
 		// Reset dirty flag.
 		m_iDirtyCount = 0;
 	}
@@ -252,7 +312,7 @@ void qsynthOptionsForm::reject (void)
 	// Check if there's any pending changes...
 	if (m_iDirtyCount > 0) {
 		switch (QMessageBox::warning(this,
-			QSYNTH_TITLE ": " + tr("Warning"),
+			tr("Warning"),
 			tr("Some options have been changed.") + "\n\n" +
 			tr("Do you want to apply the changes?"),
 			QMessageBox::Apply | QMessageBox::Discard | QMessageBox::Cancel)) {
@@ -282,6 +342,76 @@ void qsynthOptionsForm::optionsChanged()
 }
 
 
+// Custom color palette theme manager.
+void qsynthOptionsForm::editCustomColorThemes (void)
+{
+	qsynthPaletteForm form(this);
+	form.setSettings(&m_pOptions->settings());
+
+	QString sCustomColorTheme;
+	int iDirtyCustomColorTheme = 0;
+
+	const int iCustomColorTheme
+		= m_ui.CustomColorThemeComboBox->currentIndex();
+	if (iCustomColorTheme > 0) {
+		sCustomColorTheme = m_ui.CustomColorThemeComboBox->itemText(
+			iCustomColorTheme);
+		form.setPaletteName(sCustomColorTheme);
+	}
+
+	if (form.exec() == QDialog::Accepted) {
+		sCustomColorTheme = form.paletteName();
+		++iDirtyCustomColorTheme;
+	}
+
+	if (iDirtyCustomColorTheme > 0 || form.isDirty()) {
+		resetCustomColorThemes(sCustomColorTheme);
+		optionsChanged();
+	}
+}
+
+
+// Custom color palette themes settler.
+void qsynthOptionsForm::resetCustomColorThemes (
+	const QString& sCustomColorTheme )
+{
+	m_ui.CustomColorThemeComboBox->clear();
+	m_ui.CustomColorThemeComboBox->addItem(
+		tr(g_pszDefName));
+	m_ui.CustomColorThemeComboBox->addItems(
+		qsynthPaletteForm::namedPaletteList(&m_pOptions->settings()));
+
+	int iCustomColorTheme = 0;
+	if (!sCustomColorTheme.isEmpty()) {
+		iCustomColorTheme = m_ui.CustomColorThemeComboBox->findText(
+			sCustomColorTheme);
+		if (iCustomColorTheme < 0)
+			iCustomColorTheme = 0;
+	}
+	m_ui.CustomColorThemeComboBox->setCurrentIndex(iCustomColorTheme);
+}
+
+
+// Custom widget style themes settler.
+void qsynthOptionsForm::resetCustomStyleThemes (
+	const QString& sCustomStyleTheme )
+{
+	m_ui.CustomStyleThemeComboBox->clear();
+	m_ui.CustomStyleThemeComboBox->addItem(
+		tr(g_pszDefName));
+	m_ui.CustomStyleThemeComboBox->addItems(QStyleFactory::keys());
+
+	int iCustomStyleTheme = 0;
+	if (!sCustomStyleTheme.isEmpty()) {
+		iCustomStyleTheme = m_ui.CustomStyleThemeComboBox->findText(
+			sCustomStyleTheme);
+		if (iCustomStyleTheme < 0)
+			iCustomStyleTheme = 0;
+	}
+	m_ui.CustomStyleThemeComboBox->setCurrentIndex(iCustomStyleTheme);
+}
+
+
 // Stabilize current form state.
 void qsynthOptionsForm::stabilizeForm()
 {
