@@ -1,7 +1,7 @@
 // qsynthOptionsForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2018, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -44,19 +44,26 @@ public:
 
 	void setup(qsynthOptions *pOptions);
 
-public slots:
+protected slots:
 
 	void optionsChanged();
 
 	void chooseMessagesFont();
 	void browseMessagesLogPath();
-	void stabilizeForm();
 
-protected slots:
+	void editCustomColorThemes();
 
 	void accept();
 	void reject();
 
+protected:
+
+	// Custom color/style themes settlers.
+	void resetCustomColorThemes(const QString& sCustomColorTheme);
+	void resetCustomStyleThemes(const QString& sCustomStyleTheme);
+
+	void stabilizeForm();
+
 private:
 
 	// The Qt-designer UI struct...
