@@ -152,12 +152,12 @@ static void qsynth_settings_foreach (
 	case FLUID_STR_TYPE:
 	{
 	#ifdef CONFIG_FLUID_SETTINGS_GETSTR_DEFAULT
-		char *pszDefault = NULL;
+		char *pszDefault = nullptr;
 		::fluid_settings_getstr_default(pFluidSettings, pszName, &pszDefault);
 	#else
 		const char *pszDefault = ::fluid_settings_getstr_default(pFluidSettings, pszName);
 	#endif
-		char *pszCurrent = NULL;
+		char *pszCurrent = nullptr;
 	#ifdef CONFIG_FLUID_SETTINGS_DUPSTR
 		::fluid_settings_dupstr(pFluidSettings, pszName, &pszCurrent);
 	#else
@@ -192,8 +192,8 @@ qsynthSetupForm::qsynthSetupForm (
 	m_ui.setupUi(this);
 
 	// No settings descriptor initially (the caller will set it).
-	m_pSetup = NULL;
-	m_pOptions = NULL;
+	m_pSetup = nullptr;
+	m_pOptions = nullptr;
 
 	// Initialize dirty control state.
 	m_iDirtySetup = 0;
@@ -383,7 +383,7 @@ void qsynthSetupForm::setComboBoxCurrentText (
 void qsynthSetupForm::setup ( qsynthOptions *pOptions, qsynthEngine *pEngine, bool bNew )
 {
 	// Check this first.
-	if (pOptions == NULL || pEngine == NULL)
+	if (pOptions == nullptr || pEngine == nullptr)
 		return;
 
 	// Set reference descriptors.
@@ -391,7 +391,7 @@ void qsynthSetupForm::setup ( qsynthOptions *pOptions, qsynthEngine *pEngine, bo
 	m_pSetup = pEngine->setup();
 
 	// Update caption.
-	setWindowTitle(QSYNTH_TITLE ": " + tr("Setup") + " [" + pEngine->name() + "]");
+	setWindowTitle(pEngine->name() + " - " + tr("Setup"));
 
 	// Start clean?
 	m_iDirtyCount = 0;
@@ -410,7 +410,7 @@ void qsynthSetupForm::setup ( qsynthOptions *pOptions, qsynthEngine *pEngine, bo
 	// Set data context.
 	data.pSetup    = m_pSetup;
 	data.pListView = m_ui.SettingsListView;
-	data.pListItem = NULL;
+	data.pListItem = nullptr;
 	// And start filling it in...
 	::fluid_settings_foreach(m_pSetup->fluid_settings(), &data, qsynth_settings_foreach);
 
@@ -502,7 +502,7 @@ void qsynthSetupForm::setup ( qsynthOptions *pOptions, qsynthEngine *pEngine, bo
 	// Load the soundfonts view.
 	m_ui.SoundFontListView->clear();
 	m_ui.SoundFontListView->setUpdatesEnabled(false);
-	QTreeWidgetItem *pItem = NULL;
+	QTreeWidgetItem *pItem = nullptr;
 	if (pEngine->pSynth) {
 		// Load soundfont view from actual synth stack...
 		int cSoundFonts = ::fluid_synth_sfcount(pEngine->pSynth);
@@ -613,7 +613,7 @@ void qsynthSetupForm::reject (void)
 	// Check if there's any pending changes...
 	if (m_iDirtyCount > 0) {
 		switch (QMessageBox::warning(this,
-			QSYNTH_TITLE ": " + tr("Warning"),
+			tr("Warning"),
 			tr("Some settings have been changed.") + "\n\n" +
 			tr("Do you want to apply the changes?"),
 			QMessageBox::Apply | QMessageBox::Discard | QMessageBox::Cancel)) {
@@ -662,8 +662,8 @@ void qsynthSetupForm::updateMidiDevices ( const QString& sMidiDriver )
 {
 	qsynth_settings_data data;
 	data.pSetup    = m_pSetup;
-	data.pListView = NULL;
-	data.pListItem = NULL;
+	data.pListView = nullptr;
+	data.pListItem = nullptr;
 
 	// MIDI Device combobox options;
 	QString sOldText = m_ui.MidiDeviceComboBox->currentText();
@@ -695,8 +695,8 @@ void qsynthSetupForm::updateAudioDevices ( const QString& sAudioDriver )
 {
 	qsynth_settings_data data;
 	data.pSetup    = m_pSetup;
-	data.pListView = NULL;
-	data.pListItem = NULL;
+	data.pListView = nullptr;
+	data.pListItem = nullptr;
 
 	// Audio Device combobox options;
 	QString sOldText = m_ui.AudioDeviceComboBox->currentText();
@@ -797,7 +797,7 @@ void qsynthSetupForm::contextMenuRequested ( const QPoint& pos )
 	int iItem = 0;
 	int iItemCount = 0;
 	QTreeWidgetItem *pItem = m_ui.SoundFontListView->itemAt(pos);
-	if (pItem == NULL)
+	if (pItem == nullptr)
 		pItem = m_ui.SoundFontListView->currentItem();
 	if (pItem) {
 		iItem = m_ui.SoundFontListView->indexOfTopLevelItem(pItem);
@@ -812,7 +812,7 @@ void qsynthSetupForm::contextMenuRequested ( const QPoint& pos )
 		QIcon(":/images/open1.png"),
 		tr("Open..."), this, SLOT(openSoundFont()));
 	menu.addSeparator();
-	bool bEnabled = (pItem != NULL);
+	bool bEnabled = (pItem != nullptr);
 	pAction = menu.addAction(
 		QIcon(":/images/edit1.png"),
 		tr("Edit"), this, SLOT(editSoundFont()));
@@ -853,14 +853,11 @@ void qsynthSetupForm::refreshSoundFonts (void)
 // Browse for a soundfont file on the filesystem.
 void qsynthSetupForm::openSoundFont (void)
 {
-	QStringList soundfonts = QFileDialog::getOpenFileNames(
-		this,										// Parent
-		QSYNTH_TITLE ": " + tr("Soundfont files"),	// Caption.
-		m_pOptions->sSoundFontDir,                  // Start here.
-		tr("Soundfont files") + " (*.sf2 *.SF2 *.sf3 *.SF3)" // Filter files.
-	);
+	QStringList soundfonts = QFileDialog::getOpenFileNames(this,
+		tr("Soundfont files"), m_pOptions->sSoundFontDir,
+		tr("Soundfont files") + " (*.sf2 *.SF2 *.sf3 *.SF3)");
 
-	QTreeWidgetItem *pItem = NULL;
+	QTreeWidgetItem *pItem = nullptr;
 
 	// For avery selected soundfont to load...
 	QStringListIterator iter(soundfonts);
@@ -872,7 +869,7 @@ void qsynthSetupForm::openSoundFont (void)
 			if (!m_ui.SoundFontListView->findItems(
 					sSoundFont, Qt::MatchExactly, 1).isEmpty() &&
 				QMessageBox::warning(this,
-					QSYNTH_TITLE ": " + tr("Warning"),
+					tr("Warning"),
 					tr("Soundfont file already on list") + ":\n\n" +
 					"\"" + sSoundFont + "\"\n\n" +
 					tr("Add anyway?"),
@@ -881,7 +878,7 @@ void qsynthSetupForm::openSoundFont (void)
 				continue;
 			}
 			// Start inserting in the current selected or last item...
-			if (pItem == NULL) {
+			if (pItem == nullptr) {
 				pItem = m_ui.SoundFontListView->currentItem();
 				if (pItem)
 					pItem->setSelected(false);
@@ -902,7 +899,7 @@ void qsynthSetupForm::openSoundFont (void)
 			}
 		} else {
 			QMessageBox::critical(this,
-				QSYNTH_TITLE ": " + tr("Error"),
+				tr("Error"),
 				tr("Failed to add soundfont file") + ":\n\n" +
 				"\"" + sSoundFont + "\"\n\n" +
 				tr("Please, check for a valid soundfont file."),
