@@ -1,7 +1,7 @@
 // qsynthTabBar.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -30,8 +30,8 @@
 
 // Common icon set.
 static int    g_iIconRefCount = 0;
-static QIcon *g_pIconLedOn    = NULL;
-static QIcon *g_pIconLedOff   = NULL;
+static QIcon *g_pIconLedOn    = nullptr;
+static QIcon *g_pIconLedOff   = nullptr;
 
 
 //-------------------------------------------------------------------------
@@ -56,8 +56,8 @@ qsynthTabBar::~qsynthTabBar (void)
 	if (--g_iIconRefCount == 0) {
 		delete g_pIconLedOn;
 		delete g_pIconLedOff;
-		g_pIconLedOn  = NULL;
-		g_pIconLedOff = NULL;
+		g_pIconLedOn  = nullptr;
+		g_pIconLedOff = nullptr;
 	}
 }
 
